diff --git a/Makefile.am b/Makefile.am
index cf35770ba7..d250fef228 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -661,17 +661,17 @@ SUPPORTED_SYSTEMS ?= x86_64-linux i686-linux armhf-linux aarch64-linux
 BINARY_TARBALLS =							\
   $(foreach system,$(SUPPORTED_SYSTEMS),guix-binary.$(system).tar.xz)
 
-# Systems supported by GuixSD.
-GUIXSD_SUPPORTED_SYSTEMS ?= x86_64-linux i686-linux
+# Systems supported by Guix System.
+GUIX_SYSTEM_SUPPORTED_SYSTEMS ?= x86_64-linux i686-linux
 
-# Systems for which we build GuixSD VMs.
-GUIXSD_VM_SYSTEMS ?= x86_64-linux
+# Systems for which we build Guix System VMs.
+GUIX_SYSTEM_VM_SYSTEMS ?= x86_64-linux
 
-# Prefix of the GuixSD installation image file name.
-GUIXSD_IMAGE_BASE = guixsd-install-$(PACKAGE_VERSION)
+# Prefix of the Guix System installation image file name.
+GUIX_SYSTEM_IMAGE_BASE = guix-system-install-$(PACKAGE_VERSION)
 
-# Prefix of the GuixSD VM image file name.
-GUIXSD_VM_IMAGE_BASE = guixsd-vm-image-$(PACKAGE_VERSION)
+# Prefix of the Guix System VM image file name.
+GUIX_SYSTEM_VM_IMAGE_BASE = guix-system-vm-image-$(PACKAGE_VERSION)
 
 # The release process works in several phases:
 #
@@ -680,7 +680,7 @@ GUIXSD_VM_IMAGE_BASE = guixsd-vm-image-$(PACKAGE_VERSION)
 #   2. Update the 'guix' package so that it corresponds to the 'vX.Y' tag.
 #   3. Build the binary tarballs for that 'guix' package.
 #   4. Update the 'guix' package again.
-#   5. Build the GuixSD installation images.  The images will run 'guix'
+#   5. Build the Guix System installation images.  The images will run 'guix'
 #      corresponding to 'vX.Y' + 1 commit, and they will install 'vX.Y'.
 #
 # This 'release' target takes care of everything and copies the resulting
@@ -713,32 +713,32 @@ release: dist
 	   "`git rev-parse HEAD`"
 	git add $(top_srcdir)/gnu/packages/package-management.scm
 	git commit -m "gnu: guix: Update to `git rev-parse HEAD | cut -c1-7`."
-	for system in $(GUIXSD_SUPPORTED_SYSTEMS) ; do					\
+	for system in $(GUIX_SYSTEM_SUPPORTED_SYSTEMS) ; do				\
 	  image=`$(top_builddir)/pre-inst-env						\
 	    guix system disk-image							\
 	    --file-system-type=iso9660							\
             --system=$$system								\
 	    gnu/system/install.scm` ;							\
 	  if [ ! -f "$$image" ] ; then							\
-	    echo "failed to produced GuixSD installation image for $$system" >&2 ;	\
+	    echo "failed to produced Guix System installation image for $$system" >&2 ;	\
 	    exit 1 ;									\
 	  fi ;										\
-	  xz < "$$image" > "$(releasedir)/$(GUIXSD_IMAGE_BASE).$$system.iso.xz.tmp" ;	\
-	  mv "$(releasedir)/$(GUIXSD_IMAGE_BASE).$$system.iso.xz.tmp"			\
-	     "$(releasedir)/$(GUIXSD_IMAGE_BASE).$$system.iso.xz" ;			\
+	  xz < "$$image" > "$(releasedir)/$(GUIX_SYSTEM_IMAGE_BASE).$$system.iso.xz.tmp" ;	\
+	  mv "$(releasedir)/$(GUIX_SYSTEM_IMAGE_BASE).$$system.iso.xz.tmp"		\
+	     "$(releasedir)/$(GUIX_SYSTEM_IMAGE_BASE).$$system.iso.xz" ;		\
 	done
-	for system in $(GUIXSD_VM_SYSTEMS) ; do						\
+	for system in $(GUIX_SYSTEM_VM_SYSTEMS) ; do					\
 	  image=`$(top_builddir)/pre-inst-env						\
 	    guix system vm-image							\
 	    --system=$$system								\
 	    gnu/system/examples/vm-image.tmpl` ;					\
 	  if [ ! -f "$$image" ] ; then							\
-	    echo "failed to produced GuixSD VM image for $$system" >&2 ;		\
+	    echo "failed to produced Guix System VM image for $$system" >&2 ;		\
 	    exit 1 ;									\
 	  fi ;										\
-	  xz < "$$image" > "$(releasedir)/$(GUIXSD_VM_IMAGE_BASE).$$system.xz.tmp" ;	\
-	  mv "$(releasedir)/$(GUIXSD_VM_IMAGE_BASE).$$system.xz.tmp"			\
-	     "$(releasedir)/$(GUIXSD_VM_IMAGE_BASE).$$system.xz" ;			\
+	  xz < "$$image" > "$(releasedir)/$(GUIX_SYSTEM_VM_IMAGE_BASE).$$system.xz.tmp" ;	\
+	  mv "$(releasedir)/$(GUIX_SYSTEM_VM_IMAGE_BASE).$$system.xz.tmp"		\
+	     "$(releasedir)/$(GUIX_SYSTEM_VM_IMAGE_BASE).$$system.xz" ;			\
 	done
 	@echo
 	@echo "Congratulations!  All the release files are now in $(releasedir)."
diff --git a/doc/guix.texi b/doc/guix.texi
index b0837b36fa..1831f9e5bb 100644
--- a/doc/guix.texi
+++ b/doc/guix.texi
@@ -1866,7 +1866,7 @@ about their support in GNU/Linux.
 
 An ISO-9660 installation image that can be written to a USB stick or
 burnt to a DVD can be downloaded from
-@indicateurl{https://alpha.gnu.org/gnu/guix/guixsd-install-@value{VERSION}.@var{system}.iso.xz},
+@indicateurl{https://alpha.gnu.org/gnu/guix/guix-system-install-@value{VERSION}.@var{system}.iso.xz},
 where @var{system} is one of:
 
 @table @code
@@ -1882,8 +1882,8 @@ Make sure to download the associated @file{.sig} file and to verify the
 authenticity of the image against it, along these lines:
 
 @example
-$ wget https://alpha.gnu.org/gnu/guix/guixsd-install-@value{VERSION}.@var{system}.iso.xz.sig
-$ gpg --verify guixsd-install-@value{VERSION}.@var{system}.iso.xz.sig
+$ wget https://alpha.gnu.org/gnu/guix/guix-system-install-@value{VERSION}.@var{system}.iso.xz.sig
+$ gpg --verify guix-system-install-@value{VERSION}.@var{system}.iso.xz.sig
 @end example
 
 If that command fails because you do not have the required public key,
@@ -1910,7 +1910,7 @@ To copy the image to a USB stick, follow these steps:
 Decompress the image using the @command{xz} command:
 
 @example
-xz -d guixsd-install-@value{VERSION}.@var{system}.iso.xz
+xz -d guix-system-install-@value{VERSION}.@var{system}.iso.xz
 @end example
 
 @item
@@ -1919,7 +1919,7 @@ its device name.  Assuming that the USB stick is known as @file{/dev/sdX},
 copy the image with:
 
 @example
-dd if=guixsd-install-@value{VERSION}.@var{system}.iso of=/dev/sdX
+dd if=guix-system-install-@value{VERSION}.@var{system}.iso of=/dev/sdX
 sync
 @end example
 
@@ -1935,7 +1935,7 @@ To copy the image to a DVD, follow these steps:
 Decompress the image using the @command{xz} command:
 
 @example
-xz -d guixsd-install-@value{VERSION}.@var{system}.iso.xz
+xz -d guix-system-install-@value{VERSION}.@var{system}.iso.xz
 @end example
 
 @item
@@ -1944,7 +1944,7 @@ its device name.  Assuming that the DVD drive is known as @file{/dev/srX},
 copy the image with:
 
 @example
-growisofs -dvd-compat -Z /dev/srX=guixsd-install-@value{VERSION}.@var{system}.iso
+growisofs -dvd-compat -Z /dev/srX=guix-system-install-@value{VERSION}.@var{system}.iso
 @end example
 
 Access to @file{/dev/srX} usually requires root privileges.
@@ -2352,7 +2352,7 @@ Create a disk image that will hold the installed system.  To make a
 qcow2-formatted disk image, use the @command{qemu-img} command:
 
 @example
-qemu-img create -f qcow2 guixsd.img 50G
+qemu-img create -f qcow2 guix-system.img 50G
 @end example
 
 The resulting file will be much smaller than 50 GB (typically less than
@@ -2364,8 +2364,8 @@ Boot the USB installation image in an VM:
 @example
 qemu-system-x86_64 -m 1024 -smp 1 \
   -net user -net nic,model=virtio -boot menu=on \
-  -drive file=guixsd-install-@value{VERSION}.@var{system}.iso \
-  -drive file=guixsd.img
+  -drive file=guix-system-install-@value{VERSION}.@var{system}.iso \
+  -drive file=guix-system.img
 @end example
 
 The ordering of the drives matters.
@@ -2380,7 +2380,7 @@ You're now root in the VM, proceed with the installation process.
 @end enumerate
 
 Once installation is complete, you can boot the system that's on your
-@file{guixsd.img} image.  @xref{Running Guix in a VM}, for how to do
+@file{guix-system.img} image.  @xref{Running Guix in a VM}, for how to do
 that.
 
 @node Building the Installation Image
@@ -23387,7 +23387,7 @@ system configuration file.  You can then load the image and launch a
 Docker container using commands like the following:
 
 @example
-image_id="$(docker load < guixsd-docker-image.tar.gz)"
+image_id="$(docker load < guix-system-docker-image.tar.gz)"
 docker run -e GUIX_NEW_SYSTEM=/var/guix/profiles/system \\
     --entrypoint /var/guix/profiles/system/profile/bin/guile \\
     $image_id /var/guix/profiles/system/boot
@@ -23573,7 +23573,7 @@ example graph.
 @cindex virtual machine
 To run Guix in a virtual machine (VM), one can either use the
 pre-built Guix VM image distributed at
-@indicateurl{https://alpha.gnu.org/gnu/guix/guixsd-vm-image-@value{VERSION}.@var{system}.xz}
+@indicateurl{https://alpha.gnu.org/gnu/guix/guix-system-vm-image-@value{VERSION}.@var{system}.xz}
 , or build their own virtual machine image using @command{guix system
 vm-image} (@pxref{Invoking guix system}).  The returned image is in
 qcow2 format, which the @uref{http://qemu.org/, QEMU emulator} can
diff --git a/gnu/bootloader/extlinux.scm b/gnu/bootloader/extlinux.scm
index b48596c496..ebd99a2207 100644
--- a/gnu/bootloader/extlinux.scm
+++ b/gnu/bootloader/extlinux.scm
@@ -57,10 +57,10 @@ corresponding to old generations of the system."
     #~(call-with-output-file #$output
         (lambda (port)
           (let ((timeout #$(bootloader-configuration-timeout config)))
-            (format port "# This file was generated from your GuixSD configuration.  Any changes
+            (format port "# This file was generated from your Guix System configuration.  Any changes
 # will be lost upon reconfiguration.
 UI menu.c32
-MENU TITLE GuixSD Boot Options
+MENU TITLE Guix System Boot Options
 PROMPT ~a
 TIMEOUT ~a~%"
                     (if (> timeout 0) 1 0)
diff --git a/gnu/build/vm.scm b/gnu/build/vm.scm
index 0aef73d26d..3f41771ecb 100644
--- a/gnu/build/vm.scm
+++ b/gnu/build/vm.scm
@@ -145,8 +145,8 @@ the #:references-graphs parameter of 'derivation'."
 
   (apply invoke qemu "-nographic" "-no-reboot"
          "-m" (number->string memory-size)
-         "-object" "rng-random,filename=/dev/urandom,id=guixsd-vm-rng"
-         "-device" "virtio-rng-pci,rng=guixsd-vm-rng"
+         "-object" "rng-random,filename=/dev/urandom,id=guix-system-vm-rng"
+         "-device" "virtio-rng-pci,rng=guix-system-vm-rng"
          "-virtfs"
          (string-append "local,id=store_dev,path="
                         (%store-directory)
@@ -422,7 +422,7 @@ SYSTEM-DIRECTORY is the name of the directory of the 'system' derivation."
             (string-append "boot/grub/grub.cfg=" config-file))))
 
 (define* (make-iso9660-image grub config-file os-drv target
-                             #:key (volume-id "GuixSD_image") (volume-uuid #f)
+                             #:key (volume-id "Guix_System_image") (volume-uuid #f)
                              register-closures? (closures '()))
   "Given a GRUB package, creates an iso image as TARGET, using CONFIG-FILE as
 GRUB configuration and OS-DRV as the stuff in it."
@@ -550,7 +550,7 @@ passing it a directory name where it is mounted."
           (lambda (port)
             (format port
                     "insmod part_msdos~@
-                    search --set=root --label GuixSD_image~@
+                    search --set=root --label Guix_System_image~@
                     configfile /boot/grub/grub.cfg~%")))
 
         (display "creating EFI firmware image...")
diff --git a/gnu/ci.scm b/gnu/ci.scm
index 2c04b7189d..05e24655ad 100644
--- a/gnu/ci.scm
+++ b/gnu/ci.scm
@@ -132,7 +132,7 @@ SYSTEM."
     "i586-pc-gnu"                                 ;aka. GNU/Hurd
     "i686-w64-mingw32"))
 
-(define %guixsd-supported-systems
+(define %guix-system-supported-systems
   '("x86_64-linux" "i686-linux" "armhf-linux"))
 
 (define %u-boot-systems
@@ -161,7 +161,7 @@ system.")
   (define MiB
     (expt 2 20))
 
-  (if (member system %guixsd-supported-systems)
+  (if (member system %guix-system-supported-systems)
       (if (member system %u-boot-systems)
           (list (->job 'flash-image
                        (run-with-store store
@@ -235,7 +235,7 @@ system.")
             (system-test-value test))))
 
       `((derivation . ,(derivation-file-name drv))
-        (description . ,(format #f "GuixSD '~a' system test"
+        (description . ,(format #f "Guix System '~a' system test"
                                 (system-test-name test)))
         (long-description . ,(system-test-description test))
         (license . ,(license-name gpl3+))
@@ -250,7 +250,7 @@ system.")
                                 "." system))))
       (cons name (test->thunk test))))
 
-  (if (and (member system %guixsd-supported-systems)
+  (if (and (member system %guix-system-supported-systems)
 
            ;; XXX: Our build farm has too few ARMv7 machines and they are very
            ;; slow, so skip system tests there.
@@ -269,8 +269,8 @@ system.")
   (define (->alist drv)
     `((derivation . ,(derivation-file-name drv))
       (description . "Stand-alone binary Guix tarball")
-      (long-description . "This is a tarball containing binaries of Guix and
-all its dependencies, and ready to be installed on non-GuixSD distributions.")
+      (long-description . "This is a tarball containing binaries of Guix and all
+its dependencies, and ready to be installed on non-Guix System distributions.")
       (license . ,(license-name gpl3+))
       (home-page . ,%guix-home-page-url)
       (maintainers . ("bug-guix@gnu.org"))))
diff --git a/gnu/installer/newt/welcome.scm b/gnu/installer/newt/welcome.scm
index eec98e291a..317234cbb5 100644
--- a/gnu/installer/newt/welcome.scm
+++ b/gnu/installer/newt/welcome.scm
@@ -92,8 +92,8 @@ we want this page to occupy all the screen space available."
 the page. Ask the user to choose between manual installation, graphical
 installation and reboot."
   (run-menu-page
-   (G_ "GNU GuixSD install")
-   (G_ "Welcome to GNU GuixSD installer!
+   (G_ "GNU Guix System install")
+   (G_ "Welcome to GNU Guix System installer!
 
 Please note that the present graphical installer is still under heavy \
 development, so you might want to prefer using the shell based process. \
diff --git a/gnu/packages/audio.scm b/gnu/packages/audio.scm
index d77ad3d1c4..e59fae4f32 100644
--- a/gnu/packages/audio.scm
+++ b/gnu/packages/audio.scm
@@ -2270,7 +2270,7 @@ for experimenting with sound synthesis and algorithmic composition.
 SuperCollider requires jackd to be installed in your user profile and your
 user must be allowed to access the realtime features of the kernel.  Search
 for \"realtime\" in the index of the Guix manual to learn how to achieve this
-using GuixSD.")
+using Guix System.")
     (license license:gpl2+)))
 
 (define-public raul
diff --git a/gnu/packages/backup.scm b/gnu/packages/backup.scm
index f70b67bb7f..6e705d8a71 100644
--- a/gnu/packages/backup.scm
+++ b/gnu/packages/backup.scm
@@ -809,7 +809,7 @@ used, does not require any special software, on top of SSH.")
                     (output-dir
                      (assoc-ref outputs "out"))
 
-                    ;; Just a default... not so useful on guixsd though
+                    ;; Just a default... not so useful on Guix System though.
                     ;; You probably want to a service with file(s) to point to.
                     (confdir "/etc/dirvish")
 
diff --git a/gnu/packages/crypto.scm b/gnu/packages/crypto.scm
index e0d4f27874..90995d772b 100644
--- a/gnu/packages/crypto.scm
+++ b/gnu/packages/crypto.scm
@@ -306,7 +306,7 @@ secure operations. ")
              (lambda _
                (invoke "./worgen" "8-12" "top1000.txt" "3-10" "top400nouns.txt"
                        "3-6" "top150adjectives.txt" "3-6")
-               (invoke "./eschalot" "-r" "^guix|^guixsd")
+               (invoke "./eschalot" "-r" "^guix|^geeks")
                (invoke "./eschalot" "-r" "^gnu|^free")
                (invoke "./eschalot" "-r" "^cyber|^hack")
                (invoke "./eschalot" "-r" "^troll")))
diff --git a/gnu/packages/curl.scm b/gnu/packages/curl.scm
index 822fe17036..2d2b9c2c7c 100644
--- a/gnu/packages/curl.scm
+++ b/gnu/packages/curl.scm
@@ -108,9 +108,9 @@
              (("/bin/sh") (which "sh")))
 
            ;; XXX FIXME: Test #1510 seems to work on some machines and not
-           ;; others, possibly based on the kernel version.  It works on GuixSD
-           ;; on x86_64 with linux-libre-4.1, but fails on Hydra for both i686
-           ;; and x86_64 with the following error:
+           ;; others, possibly based on the kernel version.  It works on Guix
+           ;; System on x86_64 with linux-libre-4.1, but fails on Hydra for
+           ;; both i686 and x86_64 with the following error:
            ;;
            ;; test 1510...[HTTP GET connection cache limit (CURLOPT_MAXCONNECTS)]
            ;;
diff --git a/gnu/packages/emacs.scm b/gnu/packages/emacs.scm
index 1e76f0821c..74005972db 100644
--- a/gnu/packages/emacs.scm
+++ b/gnu/packages/emacs.scm
@@ -92,7 +92,7 @@
                                    '("eshell/esh-groups.el")))
 
                  ;; Make sure Tramp looks for binaries in the right places on
-                 ;; remote GuixSD machines, where 'getconf PATH' returns
+                 ;; remote Guix System machines, where 'getconf PATH' returns
                  ;; something bogus.
                  (substitute* "net/tramp-sh.el"
                    ;; Patch the line after "(defcustom tramp-remote-path".
diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 0344e42444..01fdc0736c 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -5161,7 +5161,7 @@ users.")
              (doc      (assoc-ref %outputs "doc"))
              (dhclient (string-append (assoc-ref %build-inputs "isc-dhcp")
                                       "/sbin/dhclient")))
-         (list "--with-systemd-logind=yes" ;In GuixSD, this is provided by elogind.
+         (list "--with-systemd-logind=yes" ; provided by elogind on Guix System
                "--with-consolekit=no"
                "--with-crypto=gnutls"
                "--disable-config-plugin-ibft"
diff --git a/gnu/packages/julia.scm b/gnu/packages/julia.scm
index a2e1264503..fa9709c40c 100644
--- a/gnu/packages/julia.scm
+++ b/gnu/packages/julia.scm
@@ -148,7 +148,7 @@
             (use-modules (ice-9 match))
             (substitute* "src/runtime_ccall.cpp"
               ;; Patch out invocations of '/sbin/ldconfig' to avoid getting
-              ;; error messages about missing '/sbin/ldconfig' on GuixSD.
+              ;; error messages about missing '/sbin/ldconfig' on Guix System.
               (("popen\\(.*ldconfig.*\\);")
                "NULL;\n")
 
diff --git a/gnu/packages/kde-frameworks.scm b/gnu/packages/kde-frameworks.scm
index 2ae5feaf52..aa81cb4af7 100644
--- a/gnu/packages/kde-frameworks.scm
+++ b/gnu/packages/kde-frameworks.scm
@@ -3487,7 +3487,7 @@ workspace.")
        ("qtsvg" ,qtsvg)
        ("qttools" ,qttools)
        ("qtx11extras" ,qtx11extras)))
-    ;; FIXME: Use GuixSD ca-bundle.crt in etc/xdg/ksslcalist and
+    ;; FIXME: Use Guix System ca-bundle.crt in etc/xdg/ksslcalist and
     ;; share/kf5/kssl/ca-bundle.crt
     ;; TODO: NixOS has nix-kde-include-dir.patch to change std-dir "include"
     ;; into "@dev@/include/". Think about whether this is needed for us, too.
diff --git a/gnu/packages/linux.scm b/gnu/packages/linux.scm
index e4a58834a9..e5ff96a831 100644
--- a/gnu/packages/linux.scm
+++ b/gnu/packages/linux.scm
@@ -1112,9 +1112,9 @@ MIDI functionality to the Linux-based operating system.")
     (outputs '("out" "pulseaudio" "jack"))
     (arguments
      `(#:configure-flags '(;; Do not install a "local" configuration targeted
-                           ;; for /etc/alsa.  On GuixSD plugins are loaded from
-                           ;; the ALSA service, and other distributions likely
-                           ;; won't use these files.
+                           ;; for /etc/alsa.  On Guix System plugins are loaded
+                           ;; from the ALSA service, and other distributions
+                           ;; likely won't use these files.
                            "--with-alsalconfdir=/tmp/noop")
        #:phases
        (modify-phases %standard-phases
@@ -1579,7 +1579,7 @@ devices.  It replaces @code{iwconfig}, which is deprecated.")
      '(#:phases
        (modify-phases %standard-phases
          ;; TODO: Patch some hardcoded "wlan0" in calibrate/calibrate.cpp to
-         ;; allow calibrating the network interface in GuixSD.
+         ;; allow calibrating the network interface in Guix System.
          (add-after 'unpack 'patch-absolute-file-names
            (lambda* (#:key inputs #:allow-other-keys)
              (let ((kmod (assoc-ref inputs "kmod")))
@@ -2379,7 +2379,7 @@ compliance.")
        #:tests? #f                                ;no tests
        #:make-flags (let ((out (assoc-ref %outputs "out")))
                       (list (string-append "PREFIX=" out)
-                            (string-append "LSB_ID=GuixSD")
+                            (string-append "LSB_ID=Guix")
                             (string-append "DISTRO_PUBKEY=/dev/null")
                             (string-append "DISTRO_PRIVKEY=/dev/null")
                             (string-append "REGDB_PUBKEY=/dev/null")
diff --git a/gnu/packages/package-management.scm b/gnu/packages/package-management.scm
index 1244cf2fc3..7bc9ccd5d5 100644
--- a/gnu/packages/package-management.scm
+++ b/gnu/packages/package-management.scm
@@ -142,8 +142,8 @@
 
                             ;; Set 'DOT_USER_PROGRAM' to the empty string so
                             ;; we don't keep a reference to Graphviz, whose
-                            ;; closure is pretty big (too big for the GuixSD
-                            ;; installation image.)
+                            ;; closure is pretty big (too big for the Guix
+                            ;; System installation image.)
                             "ac_cv_path_DOT_USER_PROGRAM=dot"
 
                             ;; To avoid problems with the length of shebangs,
diff --git a/gnu/packages/polkit.scm b/gnu/packages/polkit.scm
index 0433b423eb..ba74a5c905 100644
--- a/gnu/packages/polkit.scm
+++ b/gnu/packages/polkit.scm
@@ -73,7 +73,7 @@
                  (substitute* "src/polkitbackend/polkitbackendjsauthority.cpp"
                    (("systemd") "elogind"))
 
-                 ;; GuixSD's polkit service stores actions under
+                 ;; Guix System's polkit service stores actions under
                  ;; /etc/polkit-1/actions.
                  (substitute* "src/polkitbackend/polkitbackendinteractiveauthority.c"
                    (("PACKAGE_DATA_DIR \"/polkit-1/actions\"")
diff --git a/gnu/packages/tex.scm b/gnu/packages/tex.scm
index 584b2bcfa5..5b29937672 100644
--- a/gnu/packages/tex.scm
+++ b/gnu/packages/tex.scm
@@ -185,7 +185,7 @@
           ;; ps2eps.pl uses the "gswin32c" ghostscript executable on Windows,
           ;; and the "gs" ghostscript executable on Unix. It detects Unix by
           ;; checking for the existence of the /usr/bin directory. Since
-          ;; GuixSD does not have /usr/bin, it is also detected as Windows.
+          ;; Guix System does not have /usr/bin, it is also detected as Windows.
           (lambda* (#:key inputs #:allow-other-keys)
             (substitute* "utils/ps2eps/ps2eps-src/bin/ps2eps.pl"
               (("gswin32c") "gs"))
diff --git a/gnu/packages/wicd.scm b/gnu/packages/wicd.scm
index fec39ad530..a98179032f 100644
--- a/gnu/packages/wicd.scm
+++ b/gnu/packages/wicd.scm
@@ -123,7 +123,7 @@
                        "--no-install-kde"
                        "--no-install-gnome-shell-extensions"
 
-                       "--distro=guixsd"
+                       "--distro=guix"
                        "--wicdgroup=netdev"
                        "--loggroup=root"
                        "--logperms=0640"
diff --git a/gnu/packages/xorg.scm b/gnu/packages/xorg.scm
index a029d23953..dbab90fa87 100644
--- a/gnu/packages/xorg.scm
+++ b/gnu/packages/xorg.scm
@@ -5162,7 +5162,7 @@ over Xlib, including:
              ;; version and makes builds non-reproducible.
              "--with-os-name=GNU"
 
-             "--with-os-vendor=GuixSD"    ;not strictly needed, but looks nice
+             "--with-os-vendor=Guix"      ; not strictly needed, but looks nice
 
 
              ;; For the log file, etc.
diff --git a/gnu/services/base.scm b/gnu/services/base.scm
index 67df4d1379..8b0efa4fd0 100644
--- a/gnu/services/base.scm
+++ b/gnu/services/base.scm
@@ -331,7 +331,7 @@ seconds after @code{SIGTERM} has been sent are terminated with
   `(("fstab" ,(plain-file "fstab"
                           (string-append
                            "\
-# This file was generated from your GuixSD configuration.  Any changes
+# This file was generated from your Guix System configuration.  Any changes
 # will be lost upon reboot or reconfiguration.\n\n"
                            (string-join (map file-system->fstab-entry
                                              file-systems)
diff --git a/gnu/services/cups.scm b/gnu/services/cups.scm
index 715d333a71..6a622d5a0c 100644
--- a/gnu/services/cups.scm
+++ b/gnu/services/cups.scm
@@ -862,7 +862,7 @@ IPP specifications.")
         (define* (create-self-signed-certificate-if-absent
                   #:key private-key public-key (owner (getpwnam "root"))
                   (common-name (gethostname))
-                  (organization-name "GuixSD")
+                  (organization-name "Guix System")
                   (organization-unit-name "Default Self-Signed Certificate")
                   (subject-parameters `(("CN" . ,common-name)
                                         ("O" . ,organization-name)
diff --git a/gnu/services/mail.scm b/gnu/services/mail.scm
index fcaedd038b..2308d6181b 100644
--- a/gnu/services/mail.scm
+++ b/gnu/services/mail.scm
@@ -1485,7 +1485,7 @@ greyed out, instead of only later giving \"not selectable\" popup error.
         (define* (create-self-signed-certificate-if-absent
                   #:key private-key public-key (owner (getpwnam "root"))
                   (common-name (gethostname))
-                  (organization-name "GuixSD")
+                  (organization-name "Guix System")
                   (organization-unit-name "Default Self-Signed Certificate")
                   (subject-parameters `(("CN" . ,common-name)
                                         ("O" . ,organization-name)
diff --git a/gnu/services/messaging.scm b/gnu/services/messaging.scm
index 4c89a64b55..a0ae06ae1d 100644
--- a/gnu/services/messaging.scm
+++ b/gnu/services/messaging.scm
@@ -465,7 +465,7 @@ about using the hashed backend.  See also
     (log
      (maybe-string "*syslog")
      "Set logging options.  Advanced logging configuration is not yet supported
-by the GuixSD Prosody Service.  See @url{https://prosody.im/doc/logging}."
+by the Guix System Prosody Service.  See @url{https://prosody.im/doc/logging}."
      common)
 
     (pidfile
diff --git a/gnu/system/examples/vm-image.tmpl b/gnu/system/examples/vm-image.tmpl
index 4d292c1bc6..6dc67b0901 100644
--- a/gnu/system/examples/vm-image.tmpl
+++ b/gnu/system/examples/vm-image.tmpl
@@ -8,7 +8,7 @@
 (define vm-image-motd (plain-file "motd" "
 This is the GNU system.  Welcome!
 
-This instance of GuixSD is a bare-bones template for virtualized environments.
+This instance of Guix System is a bare-bones template for virtualized environments.
 
 You will probably want to do these things first if you booted in a virtual
 private server (VPS):
diff --git a/gnu/system/install.scm b/gnu/system/install.scm
index 0ba2066d11..66f69965a2 100644
--- a/gnu/system/install.scm
+++ b/gnu/system/install.scm
@@ -353,7 +353,7 @@ You have been warned.  Thanks for being so brave.\x1b[0m
      ;; the appropriate one.
      (cons* (file-system
               (mount-point "/")
-              (device (file-system-label "GuixSD_image"))
+              (device (file-system-label "Guix_System_image"))
               (type "ext4"))
 
             ;; Make /tmp a tmpfs instead of keeping the overlayfs.  This
diff --git a/gnu/system/mapped-devices.scm b/gnu/system/mapped-devices.scm
index a874666463..5c72459582 100644
--- a/gnu/system/mapped-devices.scm
+++ b/gnu/system/mapped-devices.scm
@@ -120,7 +120,7 @@
 DEVICE must be a \"/dev\" file name."
   (define aliases
     ;; Attempt to load 'modules.alias' from the current kernel, assuming we're
-    ;; on GuixSD, and assuming that corresponds to the kernel we'll be
+    ;; on Guix System, and assuming that corresponds to the kernel we'll be
     ;; installing.  Skip the whole thing if that file cannot be read.
     (catch 'system-error
       (lambda ()
diff --git a/gnu/system/vm.scm b/gnu/system/vm.scm
index e09c687a04..582408bbed 100644
--- a/gnu/system/vm.scm
+++ b/gnu/system/vm.scm
@@ -302,7 +302,7 @@ INPUTS is a list of inputs (as for packages)."
              (make-iso9660-image #$(bootloader-package bootloader)
                                  #$bootcfg-drv
                                  #$os
-                                 "/xchg/guixsd.iso"
+                                 "/xchg/guix-system.iso"
                                  #:register-closures? #$register-closures?
                                  #:closures graphs
                                  #:volume-id #$file-system-label
@@ -458,13 +458,13 @@ the image."
 
 (define* (system-docker-image os
                               #:key
-                              (name "guixsd-docker-image")
+                              (name "guix-system-docker-image")
                               register-closures?)
   "Build a docker image.  OS is the desired <operating-system>.  NAME is the
 base name to use for the output file.  When REGISTER-CLOSURES? is not #f,
 register the closure of OS with Guix in the resulting Docker image.  This only
-makes sense when you want to build a GuixSD Docker image that has Guix
-installed inside of it.  If you don't need Guix (e.g., your GuixSD Docker
+makes sense when you want to build a Guix System Docker image that has Guix
+installed inside of it.  If you don't need Guix (e.g., your Guix System Docker
 image just contains a web server that is started by the Shepherd), then you
 should set REGISTER-CLOSURES? to #f."
   (define schema
@@ -511,7 +511,7 @@ should set REGISTER-CLOSURES? to #f."
                      ;; Even as root in a VM, the initializer would fail due to
                      ;; lack of privileges if we use a root-directory that is on
                      ;; a file system that is shared with the host (e.g., /tmp).
-                     (root-directory "/guixsd-system-root"))
+                     (root-directory "/guix-system-root"))
                 (set-path-environment-variable "PATH" '("bin" "sbin") '(#+tar))
                 (mkdir root-directory)
                 (initialize root-directory)
@@ -610,7 +610,7 @@ to USB sticks meant to be read-only."
 
   (define root-label
     ;; Volume name of the root file system.
-    (normalize-label "GuixSD_image"))
+    (normalize-label "Guix_System_image"))
 
   (define root-uuid
     ;; UUID of the root file system, computed in a deterministic fashion.
@@ -862,8 +862,8 @@ with '-virtfs' options for the host file systems listed in SHARED-FS."
 
      "-no-reboot"
      "-net nic,model=virtio"
-     "-object" "rng-random,filename=/dev/urandom,id=guixsd-vm-rng"
-     "-device" "virtio-rng-pci,rng=guixsd-vm-rng"
+     "-object" "rng-random,filename=/dev/urandom,id=guix-system-vm-rng"
+     "-device" "virtio-rng-pci,rng=guix-system-vm-rng"
 
      #$@(map virtfs-option shared-fs)
      "-vga std"
diff --git a/guix/modules.scm b/guix/modules.scm
index 65928f67f2..7a579ce765 100644
--- a/guix/modules.scm
+++ b/guix/modules.scm
@@ -112,7 +112,7 @@ depends on."
                  ".scm"))
 
 (define (guix-module-name? name)
-  "Return true if NAME (a list of symbols) denotes a Guix or GuixSD module."
+  "Return true if NAME (a list of symbols) denotes a Guix or Guix System module."
   (match name
     (('guix _ ...) #t)
     (('gnu _ ...) #t)
diff --git a/nix/libstore/optimise-store.cc b/nix/libstore/optimise-store.cc
index 71dc1be07f..0e46b2a82a 100644
--- a/nix/libstore/optimise-store.cc
+++ b/nix/libstore/optimise-store.cc
@@ -114,8 +114,8 @@ void LocalStore::optimisePath_(OptimiseStats & stats, const Path & path, InodeHa
 
     /* Sometimes SNAFUs can cause files in the store to be
        modified, in particular when running programs as root under
-       GuixSD (example: $fontconfig/var/cache being modified).  Skip
-       those files.  FIXME: check the modification time. */
+       Guix System (example: $fontconfig/var/cache being modified).
+       Skip those files.  FIXME: check the modification time. */
     if (S_ISREG(st.st_mode) && (st.st_mode & S_IWUSR)) {
         printMsg(lvlError, format("skipping suspicious writable file `%1%'") % path);
         return;

diff --git a/gnu/bootloader/grub.scm b/gnu/bootloader/grub.scm
index 161e8b3d02..0750800304 100644
--- a/gnu/bootloader/grub.scm
+++ b/gnu/bootloader/grub.scm
@@ -334,7 +334,7 @@ entries corresponding to old generations of the system."
     #~(call-with-output-file #$output
         (lambda (port)
           (format port
-                  "# This file was generated from your GuixSD configuration.  Any changes
+                  "# This file was generated from your Guix System configuration.  Any changes
 # will be lost upon reconfiguration.
 ")
           #$sugar
@@ -380,7 +380,7 @@ submenu \"GNU system, old configurations...\" {~%")
       ;; system whose root is mounted at MOUNT-POINT.
       (let ((grub-install (string-append bootloader "/sbin/grub-install"))
             (install-dir (string-append mount-point "/boot"))
             ;; When installing GuixSD, it's common to mount EFI-DIR below
             ;; MOUNT-POINT rather than /boot/efi on the live image.
             (target-esp (if (file-exists? (string-append mount-point efi-dir))
                             (string-append mount-point efi-dir)
@@ -389,7 +389,7 @@ submenu \"GNU system, old configurations...\" {~%")
         ;; root partition.
         (setenv "GRUB_ENABLE_CRYPTODISK" "y")
         (unless (zero? (system* grub-install "--boot-directory" install-dir
-                                "--bootloader-id=GuixSD"
+                                "--bootloader-id=Guix System"
                                 "--efi-directory" target-esp))
           (error "failed to install GRUB (EFI)")))))
 
@@ -380,7 +380,7 @@ submenu \"GNU system, old configurations...\" {~%")
       (let ((grub-install (string-append bootloader "/sbin/grub-install"))
             (install-dir (string-append mount-point "/boot"))
-            ;; When installing GuixSD, it's common to mount EFI-DIR below
+            ;; When installing Guix System, it's common to mount EFI-DIR below
             ;; MOUNT-POINT rather than /boot/efi on the live image.
             (target-esp (if (file-exists? (string-append mount-point efi-dir))
diff --git a/gnu/tests/install.scm b/gnu/tests/install.scm
index ec29064118..51d7747cd0 100644
--- a/gnu/tests/install.scm
+++ b/gnu/tests/install.scm
@@ -47,7 +47,7 @@
 
 ;;; Commentary:
 ;;;
 ;;; Test the installation of GuixSD using the documented approach at the
 ;;; command line.
 ;;;
 ;;; Code:
@@ -204,8 +204,8 @@ reboot\n")
                                                 (guix combinators))))
                       (installation-disk-image-file-system-type "ext4")
                       (target-size (* 2200 MiB)))
-  "Run SCRIPT (a shell script following the GuixSD installation procedure) in
-OS to install TARGET-OS.  Return a VM image of TARGET-SIZE bytes containing
+  "Run SCRIPT (a shell script following the Guix System installation procedure)
+in OS to install TARGET-OS.  Return a VM image of TARGET-SIZE bytes containing
 the installed system.  The packages specified in PACKAGES will be appended to
 packages defined in installation-os."
 
@@ -47,7 +47,7 @@
 ;;; Commentary:
 ;;;
-;;; Test the installation of GuixSD using the documented approach at the
+;;; Test the installation of Guix System using the documented approach at the
 ;;; command line.
 ;;;